<?php
class vcautoresponderaddon_admin{
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Plugin_Name_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;
	
	public $enabled_vc_composer;
	public $sidebars = array();
	
	/**
	 * Define custom post type, meta option and settings.
	 *
	 * @since	1.0.0
	 */
	public function __construct( $plugin_name, $version, $loader ){
		$this->loader = $loader;
		$this->version = $version;
		$this->plugin_name = $plugin_name;
		$this->enabled_vc_composer = defined('WPB_VC_VERSION') && function_exists('vc_disable_frontend');

		/* aweber */
		add_action( 'wp_ajax_vcaweber_saveauthcode', array($this,'vcaweber_saveauthcode') );
		add_action( 'wp_ajax_nopriv_vcaweber_saveauthcode', array($this,'vcaweber_saveauthcode') );
		/* aweber */

		/* mailchimp */
		add_action( 'wp_ajax_vcmailchimp_apikeysave', array($this,'vcmailchimp_apikeysave') );
		add_action( 'wp_ajax_nopriv_vcmailchimp_apikeysave', array($this,'vcmailchimp_apikeysave') );
		/* mailchimp */

		/* getresponse */
		add_action( 'wp_ajax_vcgetresponse_apikeysave', array($this,'vcgetresponse_apikeysave') );
		add_action( 'wp_ajax_nopriv_vcgetresponse_apikeysave', array($this,'vcgetresponse_apikeysave') );
		/* getresponse */
		
		/* constantcontact */
		add_action( 'wp_ajax_vcconstantcontact_apikeysave', array($this,'vcconstantcontact_apikeysave') );
		add_action( 'wp_ajax_nopriv_vcconstantcontact_apikeysave', array($this,'vcconstantcontact_apikeysave') );
		/* constantcontact */

		/* icontact */
		add_action( 'wp_ajax_vcicontact_apikeysave', array($this,'vcicontact_apikeysave') );
		add_action( 'wp_ajax_nopriv_vcicontact_apikeysave', array($this,'vcicontact_apikeysave') );
		/* icontact */	
		
		add_action( 'wp_ajax_vcgeneralsetting_save', array($this,'vcgeneralsetting_save') );
		add_action( 'wp_ajax_nopriv_vcgeneralsetting_save', array($this,'vcgeneralsetting_save') );
		
		
		add_action( 'wp_ajax_vcsave_constantcontact', array($this,'vcsave_constantcontact') );
		add_action( 'wp_ajax_nopriv_vcsave_constantcontact', array($this,'vcsave_constantcontact') );
	}
	 
	public function register_submenu_settingpage(){
		add_submenu_page( 'options-general.php', 'VC Autoresponder Settings', 'VC Autoresponder Settings', 'manage_options', 'vc-autorespondersetting', array($this,'render_vcautoresponderaddon_settingpage') );
		add_submenu_page( 'options-general.php', 'VC Autoresponder Sidebar', 'VC Autoresponder Sidebar', 'manage_options', 'vc-autorespondersidebar', array($this,'render_vcautoresponderaddon_sidebarpage') );
	}
	 
	public function render_vcautoresponderaddon_settingpage(){
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/vcautoresponderaddon-settings.php';
	}
	
	public function save_vcaa_sidebar_postdata(){
		if( !current_user_can('edit_theme_options') )
			return false;

		if( empty($_POST['save']) || $_POST['save']!='vcaa_sidebar' )
			return false;
		
		check_admin_referer( 'vcaa_nonce_save' );
		
		$my_post = array(
			'ID'           => $_POST['post_ID'],
			'post_title'   => $_POST['post_title'],
			'post_content' => $_POST['content'],
		);
		
		if(wp_update_post( $my_post )){
			update_post_meta($_POST['post_ID'],'settings_formposition',$_POST['settings_formposition']);
			update_post_meta($_POST['post_ID'],'settings_formposition_value',$_POST['settings_formposition_value']);
			return true;
		}
		
	}
	
	public function render_vcautoresponderaddon_sidebarpage(){
		global $vc_manager, $post, $wp_registered_sidebars;
				
		$current_sidebar = $sidebar_slug = '';
		
		$message = $this->save_vcaa_sidebar_postdata();
		
		foreach($wp_registered_sidebars as $k=>$v){
			if(!isset( $_POST['vcaa_sidebar'] )){
				$sidebar_slug = $k;
				$current_sidebar = $v;
				break;
			}
			if(isset($_POST['vcaa_sidebar']) && $k == $_POST['vcaa_sidebar']){
				$sidebar_slug = $k;
				$current_sidebar = $v;
				break;
			}
		}
		
		$args = array (
			'post_type' => 'vcaa_sidebar',
			'name' => $sidebar_slug
		);
		$query = new WP_Query( $args );
		
		if( $query->have_posts() ) {
			$post = $query->post;
		} else {
			$data = array(
				'post_title' => '',
				'post_content' => '',
				'post_type' => 'vcaa_sidebar',
				'post_name' => $sidebar_slug,
				'post_status' => 'publish',
				'guid' => $sidebar_slug,
			);
			
			// Save post data
			$post_id = wp_insert_post( $data );
			$post = get_post( $post_id );
		}
		
		$post_title = $post->post_title;
		$post_content = $post->post_content;
		$post_status = $post->post_status;
		$post_name = $post->post_name;
		
		wp_reset_postdata();
		
		
		
		
		wp_enqueue_style( 'js_composer_front' );
		wp_enqueue_script( 'js_composer_front' );
		
		if( $this->enabled_vc_composer ) {
			vc_disable_frontend();
			$editor = $vc_manager->backendEditor();
			$editor->addHooksSettings();
			
			if( $this->enabled_vc_composer && version_compare(WPB_VC_VERSION, '4.9', '>=') ) {
				$editor->registerBackendJavascript();
				$editor->registerBackendCss();
				// B.C:
				visual_composer()->registerAdminCss();
				visual_composer()->registerAdminJavascript();
			}
		}
		
		
		
		do_action( 'admin_print_scripts-post.php' );
		do_action( 'admin_print_styles-post.php' );
		
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/vcautoresponderaddon-sidebar.php';
				
	}
	
	public function admin_enqueue_scripts(){
		do_action( 'admin_print_scripts-post.php' );
	}
	
	public function admin_enqueue_styles(){
		do_action( 'admin_print_styles-post.php' );
	}
	 
	public function enqueue_scripts(){
		wp_enqueue_style( 'wp-color-picker' ); 
		wp_register_script( 'vcautoresponderaddon-custom', plugin_dir_url(__FILE__) . 'js/vcautoresponderaddon.js', array('jquery','wp-color-picker'), $this->version, false );

		wp_enqueue_script('vcautoresponderaddon-custom');
		wp_localize_script('vcautoresponderaddon-custom', 'ajaxobject', array(
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			)
		);
	}
	 
	public function enqueue_styles(){
		wp_register_style( 'vcautoresponderaddon-style', plugin_dir_url(__FILE__) . 'css/vcautoresponderaddon.css' );
	 
		wp_enqueue_style('vcautoresponderaddon-style');
	}	
	 
	public function vcaweber_saveauthcode(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcaweber_saveauthcode'){
			$authinfoCODE = get_option('vcaweber_authinfoCODE');
			if($_POST['vcaweber_apikey'] != $authinfoCODE){
				require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/aweber/aweber_api.php';
				$descr = '';
				$arr = array();
				try{
					list($consumer_key, $consumer_secret, $access_key, $access_secret) = AWeberAPI::getDataFromAweberID($_POST['vcaweber_apikey']);
				}catch (AWeberAPIException $exc){
					list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
					if(isset($exc->message)){
						$descr = $exc->message;
						$descr = preg_replace('/http.*$/i', '', $descr);	
						$descr = preg_replace('/[\.\!:]+.*$/i', '', $descr); 
						$descr = '('.$descr.')';
					}
				}catch (AWeberOAuthDataMissing $exc){
					list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
				}catch (AWeberException $exc){
					list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
				}
				if (!$access_secret){
					$arr['error'] = 'Unable to connect to your AWeber Account ' .$descr;
				}else{
					$authinfo = array(
						'consumer_key' => $consumer_key,
						'consumer_secret' => $consumer_secret,
						'access_key' => $access_key,
						'access_secret' => $access_secret,
					);
					update_option('vcaweber_authinfoDB',$authinfo);
					update_option('vcaweber_authinfoCODE',$_POST['vcaweber_apikey']);
					try {
						$aweber = new AWeberAPI($consumer_key, $consumer_secret);
						$account = $aweber->getAccount($access_key, $access_secret);
						$res = $account->lists;
					}catch (AWeberException $e){
						$arr['error'] = 'Unable to connect to your AWeber Account.';
					}
				}
				echo json_encode($arr);
			}else{
				echo json_encode(array('error'=>''));
			}
			die();
		}else{
			exit;
		}
	}
	 	 
	public function vcmailchimp_apikeysave(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcmailchimp_apikeysave'){
			require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/mailchimp/MCAPI.class.php';

			$api = new MailChimp($_POST['apikey']);

			$retval = $api->get('lists');
			if (!$api->errorCode){
				update_option('vcmailchimp_apikey',$_POST['apikey']);
				echo json_encode(array('success'=>1));
			}else{
				echo json_encode(array('error'=>'Unable to connect to your Mailchimp Account.'));
			}
			die();
		}else{
			exit;
		}
	}
	 
	public function vcgetresponse_apikeysave(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcgetresponse_apikeysave'){

            $curl = curl_init();
			curl_setopt_array($curl, array(
			  CURLOPT_URL => "https://api.getresponse.com/v3/campaigns",
			  CURLOPT_RETURNTRANSFER => true,
			  CURLOPT_ENCODING => "",
			  CURLOPT_MAXREDIRS => 10,
			  CURLOPT_TIMEOUT => 0,
			  CURLOPT_FOLLOWLOCATION => true,
			  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			  CURLOPT_CUSTOMREQUEST => "GET",
			  CURLOPT_HTTPHEADER => array(
				'X-Auth-Token: api-key '.$_POST['apikey'].'',
				"Content-Type: application/json"
			  ),
			));
			$response = curl_exec($curl);
			curl_close($curl);
			$res = json_decode($response);
			if( count($res) > 0 ){
				foreach($res as $r){
					$lists[$r->campaignId] = $r->name;
				}
				$resultList['list'] = $lists;
				update_option('vcgetresponse_apikey',$_POST['apikey']);
				echo json_encode(array('success'=>1));
			}else{
				$resultList = $res;
				echo json_encode(array('error'=>'Unable to connect to your Getresponse Account.'));
			}
			die();
		}else{
			exit;
		}
	}	
	
	public function vcconstantcontact_apikeysave(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcconstantcontact_apikeysave'){		
 			 if ($_POST["ccusername"] && $_POST["ccpassword"] && $_POST["cctoken"]){
 				update_option('vcconstantcontact_apikey',$_POST["ccusername"]);
    		    update_option('vcconstantcontact_secrete', $_POST["ccpassword"]);
    		    update_option('vcconstantcontact_token',$_POST["cctoken"]);
 					echo json_encode(array('success'=>1));
 				}else{
 					echo json_encode(array('error'=>'Unable to connect to your Constant Contact Account.'));
 				}
            
		  die();
		}else{
			exit;
		}
	}	
	
	public function vcicontact_apikeysave(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcicontact_apikeysave'){
			require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/icontact/iContactApi.php';
			$data = array(
				'username' => $_POST['username'],
				'appid' => $_POST['appid'],
				'apppassword' => $_POST['apppass']
			);
			iContactApi::getInstance()->setConfig(array(
				'appId' => $data['appid'],
				'apiPassword' => $data['apppassword'],
				'apiUsername' => $data['username']
			));
			$oiContact = iContactApi::getInstance();
			try{
				$res = $oiContact->getLists();
				update_option('vcicontact_apikey',$data);
				echo json_encode(array('success'=>1));
			}catch (Exception $oException){
				echo json_encode(array('error'=>'Unable to connect to your iContact Account.'));
				//var_dump($oiContact->getErrors());
			}
			die();
		}else{
			exit;
		}
	}
	
	public function vcgeneralsetting_save(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcgeneralsetting_save'){
			update_option('vcsuccessmsgcolor',$_POST['success']);
			update_option('vcsuccessmsgtxt',$_POST['msg']);
			echo json_encode(array('success'=>1));
			die();
		}else{
			exit;
		}
	}
	
	public function vcsave_constantcontact(){
	    if(!empty($_POST['apikey']) && !empty($_POST['secrete'])){
    	    $apikey = $_POST['apikey'];
    	    $secrete = $_POST['secrete'];
    	    
    	    update_option( 'cc_tempapikey', $apikey );
            update_option( 'cc_tempsecrete', $secrete );
            echo "success";
	    }
	}
	
	public function aweberlist(){
		$arr = array('select'=>0);
		
		$authinfo = get_option('vcaweber_authinfoDB');
		
		if(!empty($authinfo)){
			require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/aweber/aweber_api.php';
			try {
				$aweber = new AWeberAPI($authinfo['consumer_key'], $authinfo['consumer_secret']);
				$account = $aweber->getAccount($authinfo['access_key'], $authinfo['access_secret']);
				$res = $account->lists;
				if($res){
					foreach ((array) $res->data['entries'] as $v){
						$arr[$v['name']] = $v['id'];
					}
				}
			}catch (AWeberException $e){
				$arr[] = 'Unable to connect to your AWeber Account.';
			}
		}
		
		return $arr; 
	}
	
	public function mailchimplist(){
		$arr = array('select'=>0);
		$apikey = get_option('vcmailchimp_apikey');
		if(!empty($apikey)){
			require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/mailchimp/MCAPI.class.php';
			
			$MailChimp = new MailChimp($apikey);
			$retval = $MailChimp->get('lists');
			
			if(isset($retval['lists'])){
				if(!empty($retval['lists'])){
					for($i=count($retval['lists'])-1;$i>=0;$i--){
						$arr[$retval['lists'][$i]['name']] = $retval['lists'][$i]['id'];
					}
				}else{
					$arr[] = 'There is no list in your account.';
				}
			}else{
				$arr[] = 'Unable to connect to your Mailchimp Account.';
			}
		}
		return $arr;
	}
	
	public function getresponselist(){
		$arr = array('select'=>0);
		$apikey = get_option('vcgetresponse_apikey');
		if(!empty($apikey)){
            $curl = curl_init();
			curl_setopt_array($curl, array(
			  CURLOPT_URL => "https://api.getresponse.com/v3/campaigns",
			  CURLOPT_RETURNTRANSFER => true,
			  CURLOPT_ENCODING => "",
			  CURLOPT_MAXREDIRS => 10,
			  CURLOPT_TIMEOUT => 0,
			  CURLOPT_FOLLOWLOCATION => true,
			  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			  CURLOPT_CUSTOMREQUEST => "GET",
			  CURLOPT_HTTPHEADER => array(
				'X-Auth-Token: api-key '.$apikey.'',
				"Content-Type: application/json"
			  ),
			));
			$response = curl_exec($curl);
			curl_close($curl);
			$res = json_decode($response);
			if( count($res) > 0 ){
				foreach($res as $r){
					$arr[$r->name] = $r->campaignId;
				}
			}else{
				$resultList = $res;
				echo json_encode(array('error'=>'Unable to connect to your Getresponse Account.'));
			}
			
		}
		return $arr;
	}
	 
	public function constantcontactlist(){
		$arr = array('select'=>0); 
        $key = get_option('vcconstantcontact_apikey');
		$secret = get_option('vcconstantcontact_secrete');
		$token = get_option('vcconstantcontact_token');
		$data = array(
			'apikey' => $key,
			'secret' => $secret,
			'token' => $token
		);
		
		$curl = curl_init();

		curl_setopt_array($curl, array(
		  CURLOPT_URL => "https://api.cc.email/v3/contact_lists?include_count=false",
		  CURLOPT_RETURNTRANSFER => true,
		  CURLOPT_ENCODING => "",
		  CURLOPT_MAXREDIRS => 10,
		  CURLOPT_TIMEOUT => 0,
		  CURLOPT_FOLLOWLOCATION => true,
		  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
		  CURLOPT_CUSTOMREQUEST => "GET",
		  CURLOPT_HTTPHEADER => array(
			'authorization: Bearer '.$token,
			'content-type: application/json'
		  ),
		));

		$response = curl_exec($curl);
		curl_close($curl);
		
		$res = json_decode($response);
		if(isset($res->lists) && !empty($res->lists)){
			foreach( $res->lists as $r ){
				$arr[$r->name] = $r->list_id;
			}
    		}else{
    			$arr = json_encode( array('msg'=> $res->error_message, 'status' => 'error') );
    		}


		return $arr;		
	}
	
	public function icontactlist(){
		$arr = array('select'=>0);
		$icontactinfo = get_option('vcicontact_apikey');
		if(!empty($icontactinfo)){
			require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/icontact/iContactApi.php';
			iContactApi::getInstance()->setConfig(array(
				'appId' => $icontactinfo['appid'],
				'apiPassword' => $icontactinfo['apppassword'],
				'apiUsername' => $icontactinfo['username']
			));
			$oiContact = iContactApi::getInstance();
			try{
				$res = $oiContact->getLists();
				foreach ($res as $v){
					$arr[$v->name] = $v->listId;
				}
			}catch (Exception $oException){
				
			}
		}
		return $arr;		
	}
	
	/**
	 * Create custom post type vcaa_sidebar.
	 *
	 * @since	1.0.0
	 */
	 public function create_custom_post_type(){
		 
		$args = array(
			'label'		=> 'Visual Autoresponder Sidebar',
			'supports'	=> array( 'title', 'editor', 'revisions' ),
			'public'	=> true,
			'show_ui'	=> false,
			'rewrite'	=> false,
			'labels' => array (
				'name' => 'Visual Autoresponder Sidebar',
			)
		);
		
		register_post_type( 'vcaa_sidebar', $args );
		
	 }
	 
	 public function vcaa_desfaultsetpost(){
		$post_types = vc_editor_post_types();
		if( !in_array('vcaa_sidebar', $post_types) ) {
			$post_types[] = 'vcaa_sidebar';
			vc_editor_set_post_types( $post_types );
		}
	}
	 
	 public function vcautoresponderform(){
		$aweberlist = $this->aweberlist();
		$mailchimplist = $this->mailchimplist();
		$getresponselist = $this->getresponselist();
		//$constantcontactlist = array();
		$constantcontactlist = $this->constantcontactlist();
		$icontactlist = $this->icontactlist();
		
		/* popup */
		vc_map(array(
			"name" => __("Popup Container","vcara"),
			"base" => "vc_autoresponder_popup_container",
			"class" => "",
			"as_parent" => array('only'=>'vc_autoresponder_form_field','except'=>''),
			"category" => __('Autoresponder','vcara'),
			"params" => array(
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"heading" => __("Title",'vcara'),
					"param_name" => "title",
					"value" => __("",'vcara'),
					"description" => __("Title text Here, if you don't want it,please leave it blank.",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"heading" => __("Popup Width",'vcara'),
					"param_name" => "popupwidth",
					"description" => __("Width should be percentage within 0 to 100.",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"heading" => __("Show Popup",'vcara'),
					"param_name" => "showpopup",
					"value" => array('Select','Onload','End of page','After scrolling midway','After X seconds'),
					"description" => __("",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"dependency"=> array('element'=>'showpopup','value'=>array('After X seconds')),
					"heading" => __("Second",'vcara'),
					"param_name" => "second",
					"value" => '0',
					"description" => __("",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"heading" => __("Animate Popup",'vcara'),
					"param_name" => "animatecls",
					"value" => array('Select','bounce','flash','pulse','rubberBand','shake','swing','tada','wobble','bounceIn','bounceInDown','bounceInLeft','bounceInRight','bounceInUp','slideInDown','slideInLeft','slideInRight','slideOutLeft','slideOutRight','slideOutUp','fadeIn','fadeInDown','fadeInDownBig','fadeInLeft','fadeInLeftBig','fadeInRight','fadeInRightBig','fadeInUp','fadeInUpBig','flip','flipInX','flipInY','flipOutX','flipOutY','rotateIn','rotateInDownLeft','rotateInDownRight','rotateInUpLeft','rotateInUpRight'),
					"description" => __("",'vcara')
				),
				array(
					"type" => "attach_image",
					"holder" => "div",
					"class" => "",
					"heading" => __("Select Background Image",'vcara'),
					"param_name" => "popupbgiamge",
					"value" => '',
					"description" => __("",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"heading" => __("Opacity",'vcara'),
					"param_name" => "popupopacity",
					"description" => __("Opacity 0 to 100 (percentage).",'vcara')
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"heading" => __("Select Background Color",'vcara'),
					"param_name" => "popupbgcolor",
					"value" => '',
					"description" => __("",'vcara')
				),
				array(
					"type" => "checkbox",
					"holder" => "div",
					"class" => "",
					"heading" => __("",'vcara'),
					"param_name" => "popupshadow",
					"value" => array("Shadow"=>"Shadow"),
					"description" => __("",'vcara')
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"dependency"=> array('element'=>'popupshadow','value'=>array('Shadow')),
					"heading" => __("Select Box Shadow Color",'vcara'),
					"param_name" => "popupshadowcolor",
					"value" => '',
					"description" => __("",'vcara')
				)
			),
			"js_view" => 'VcColumnView'
		) );	
		/* popup */
		
		vc_map( array(
			"name" => __("Autoresponder Form Container",'vcara'),
			"base" => "vc_autoresponder_form",
			"class" => "",
			"as_parent" => array('only' => 'vc_autoresponder_form_field','except'=>''),
			"category" => __('Autoresponder','vcara'),
			"group" => "General Option,Design Option",
			"params" => array(
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"heading" => __("Title",'vcara'),
					"param_name" => "title",
					"value" => __("",'vcara'),
					"group" => "General Option",
					"description" => __("Title text Here, if you don't want it,please leave it blank.",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"heading" => __("Select Autoresponder",'vcara'),
					"param_name" => "autoresponder",
					"value" => array('Select','Aweber','Mailchimp','Getresponse','Constant Contact','iContact'),
					"group" => "General Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'autoresponder','value'=>array('Aweber')),
					"heading" => __("Select List",'vcara'),
					"param_name" => "aweberlistid",
					"value" => $aweberlist,
					"group" => "General Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'autoresponder','value'=>array('Mailchimp')),
					"heading" => __("Select List",'vcara'),
					"param_name" => "mailchimplistid",
					"value" => $mailchimplist,
					"group" => "General Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'autoresponder','value'=>array('Getresponse')),
					"heading" => __("Select List",'vcara'),
					"param_name" => "getresponselistid",
					"value" => $getresponselist,
					"group" => "General Option",
					"description" => __("",'vcara')
				), 
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'autoresponder','value'=>array('Constant Contact')),
					"heading" => __("Select List",'vcara'),
					"param_name" => "constantcontactlistid",
					"value" => $constantcontactlist,
					"group" => "General Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'autoresponder','value'=>array('iContact')),
					"heading" => __("Select List",'vcara'),
					"param_name" => "icontactlistid",
					"value" => $icontactlist,
					"group" => "General Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"heading" => __("Padding",'vcara'),
					"param_name" => "padding",
					"value" => '',
					"group" => "Design Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"heading" => __("Select Title Color",'vcara'),
					"param_name" => "vcformtitlecolor",
					"value" => '',
					"group" => "Design Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"heading" => __("Select Background Type",'vcara'),
					"param_name" => "bgtype",
					"value" => array('select','video','image','Background Pattern'),
					"group" => "Design Option",
					"description" => __("if not required, let field be empty.",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'bgtype','value'=>array('video')),
					"heading" => __("Show form after X second",'vcara'),
					"param_name" => "second",
					"value" => '',
					"group" => "Design Option",
					"description" =>  __("min value should be 5.",'vcara')
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'bgtype','value'=>array('video')),
					"heading" => __("Select Video Form Background Color",'vcara'),
					"param_name" => "vcvideoformbgcolor",
					"value" => '',
					"group" => "Design Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "checkbox",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'bgtype','value'=>array('video')),
					"heading" => '',
					"param_name" => "closebtn",
					"group" => "Design Option",
					"value" => array('Close Button'=>'yes'),
					"description" =>  ''
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'bgtype','value'=>array('video')),
					"heading" => __("Video Url",'vcara'),
					"param_name" => "vcformbgvideo",
					"value" => __("",'vcara'),
					"group" => "Design Option",
					"description" => __("if not required, let field be empty.",'vcara')
				),
				array(
					"type" => "attach_image",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'bgtype','value'=>array('image')),
					"heading" => __("Background Image",'vcara'),
					"param_name" => "vcformbgimg",
					"value" => __("",'vcara'),
					"group" => "Design Option",
					"description" => __("if not required, let field be empty.",'vcara')
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'bgtype','value'=>array('Background Pattern')),
					"heading" => __("Select Background Pattern",'vcara'),
					"param_name" => "bgpattern",
					"value" => array('select', 'Microbial Mat', 'Stairs', 'Half Rombes', 'Arrows', 'Zig Zag', 'Weave', 'Upholstery', 'Starry night', 'Marrakesh', 'Rainbow bokeh', 'Carbon', 'Carbon fibre', 'Hearts', 'Argyle', 'Steps', 'Waves', 'Cross', 'Yin Yang', 'Stars', 'Brady Bunch', 'Shippo', 'Bricks', 'Seigaiha', 'Japanese cube', 'Polka dot', 'Houndstooth', 'Checkerboard', 'Diagonal checkerboard', 'Tartan', 'Madras', 'Lined paper', 'Blueprint grid', 'Tablecloth', 'Diagonal stripes', 'Cicada stripes', 'Vertical stripes', 'Horizontal stripes'),
					"group" => "Design Option",
					"description" => __("",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"heading" => __("Opacity",'vcara'),
					"param_name" => "opacity",
					"value" => '',
					"group" => "Design Option",
					"description" => __("Opacity 0 to 100 (percentage).",'vcara')
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"heading" => __("Select Background Color",'vcara'),
					"param_name" => "vcformbgcolor",
					"value" => '',
					"group" => "Design Option",
					"description" => __("",'vcara')
				)
			),
			"js_view" => 'VcColumnView'
		) );
		vc_map( array(
			"name" => __("Fields", "vcara"),
			"base" => "vc_autoresponder_form_field",
			"content_element" => true,
			"as_child" => array('except' => 'vc_autoresponder_form,vc_autoresponder_popup_container'), 
			"category" => __('Autoresponder','vcara'),
			"params" => array(
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"heading" => __("Select Field",'vcara'),
					"param_name" => "field",
					"value" => array('select','name field','email field','custom field','button field'),
					"description" => __("",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('custom field')),
					"heading" => __("Name Of Custom Field",'vcara'),
					"param_name" => "customfield",
					"value" => '',
					"description" => __("it's require for custom field.",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('name field','email field','custom field')),
					"heading" => __("Placeholder",'vcara'),
					"param_name" => "placeholder",
					"value" => '',
					"description" => __("if not required, let field be empty.",'vcara')
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('name field','email field','custom field')),
					"heading" => __("Label Text",'vcara'),
					"param_name" => "labeltxt",
					"value" => '',
					"description" =>  __("if not required, let field be empty.",'vcara')
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('name field','email field','custom field')),
					"heading" => __("Select Label Text Color",'vcara'),
					"param_name" => "vclabletxtcolor",
					"value" => '',
					"description" => __("",'vcara')
				),
				array(
					"type" => "checkbox",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('name field','email field','custom field')),
					"heading" => '',
					"param_name" => "require",
					"value" => array('Require'=>'yes'),
					"description" =>  ''
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'require','value'=>array('yes')),
					"heading" => __('Error Text','vcara'),
					"param_name" => "errortxt",
					"value" => '',
					"description" =>  ''
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'require','value'=>array('yes')),
					"heading" => __('Error Text Color','vcara'),
					"param_name" => "errortxtcolor",
					"value" => '',
					"description" =>  ''
				),
				array(
					"type" => "textfield",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('button field')),
					"heading" => __('Button Text','vcara'),
					"param_name" => "buttontxt",
					"value" => '',
					"description" =>  ''
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('button field')),
					"heading" => __('Button Background Color','vcara'),
					"param_name" => "buttonbgcolor",
					"value" => '',
					"description" =>  ''
				),
				array(
					"type" => "colorpicker",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('button field')),
					"heading" => __('Button Text Color','vcara'),
					"param_name" => "buttontxtcolor",
					"value" => '',
					"description" =>  ''
				),
				array(
					"type" => "dropdown",
					"holder" => "div",
					"class" => "",
					"dependency" => array('element'=>'field','value'=>array('button field')),
					"heading" => __('Button Alignment','vcara'),
					"param_name" => "buttonalign",
					"value" => array('select','left','right','center','justify'),
					"description" =>  ''
				)				
			)
		) );
	}
}

add_action( 'vc_before_init', 'vcautoresponderformnested' );
function vcautoresponderformnested(){	
	if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
		class WPBakeryShortCode_vc_autoresponder_popup_container extends WPBakeryShortCodesContainer {
		}
	}
	if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
		class WPBakeryShortCode_vc_autoresponder_form extends WPBakeryShortCodesContainer {
		}
	}
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_vc_autoresponder_form_field extends WPBakeryShortCode {
		}
	}
}
?>