<?php
class vcautoresponderaddon{
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Plugin_Name_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * The name of the plugin specific database
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
    //public $table_name;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the Dashboard and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'vcautoresponderaddonAddon';
		$this->version = '1.0';
        /* global $wpdb;
        $this->table_name= $wpdb->prefix . ''; */
        
		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}
	
	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Loader. Orchestrates the hooks of the plugin.
	 * - i18n. Defines internationalization functionality.
	 * - Admin. Defines all hooks for the dashboard.
	 * - Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	 private function load_dependencies() {
	
		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-vcautoresponderaddon-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-vcautoresponderaddon-i18n.php';
		
		/**
		 * The class responsible for defining all actions that occur in the Dashboard.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-vcautoresponderaddon-admin.php';
		
		/**
		 * The class responsible for defining all actions that occur in the Public.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-vcautoresponderaddon-public.php';
		
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widget.php';
		
		$this->loader = new vcautoresponderaddon_loader();
		 
	 }
	 
	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Plugin_Name_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new vcautoresponderaddon_i18n();
		$plugin_i18n->set_domain( 'vcara' ); /* use text domain VCHeaderAddon */

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}
	
	private function define_admin_hooks(){
		$plugin_admin = new vcautoresponderaddon_admin($this->get_plugin_name(), $this->get_version() ,$this->get_loader());
		
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'create_custom_post_type' );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'register_submenu_settingpage' );
		$this->loader->add_action( 'vc_before_init', $plugin_admin, 'vcaa_desfaultsetpost' );
		$this->loader->add_action( 'vc_before_init', $plugin_admin, 'vcautoresponderform' );
	}
	
	private function define_public_hooks(){
		$plugin_public = new vcautoresponderaddon_public($this->get_plugin_name(), $this->get_version() );
		
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		
		$this->loader->add_action( 'wp', $plugin_public, 'vcaa_registrater_sidebars' );
		
		add_shortcode( 'vc_autoresponder_popup_container', array($plugin_public, 'vc_autoresponder_popup_container_shortcode' ) );
		add_shortcode( 'vc_autoresponder_form', array($plugin_public, 'vc_autoresponder_form_shortcode' ) );
		add_shortcode( 'vc_autoresponder_form_field', array($plugin_public, 'vc_autoresponder_form_field_shortcode' ) );
	}
	
	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Plugin_Name_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}
	
	/**
	 * Retrieve the table name of the plugin
	 *
	 * @since     1.0.0
	 * @return    string    The table name of the plugin.
	 */
	/*public function get_table_name() {
		return $this->table_name;
	}*/
		 
}
?>