<?php
class vcautoresponderaddon_public{
	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;
	
	protected $vcaa_registrater_sidebars;
	protected $enabled_vc_composer;
	
	/**
	 * Define custom post type, meta option and settings.
	 *
	 * @since	1.0.0
	 */
	public function __construct( $plugin_name, $version ){
		$version = $this->version;
		$plugin_name = $this->plugin_name;
		
		$this->enabled_vc_composer = defined('WPB_VC_VERSION') && function_exists('vc_disable_frontend');

		/* aweber */
		add_action( 'wp_ajax_vcautoresponderaddon_awebersubmit', array($this,'vcautoresponderaddon_awebersubmit') );
		add_action( 'wp_ajax_nopriv_vcautoresponderaddon_awebersubmit', array($this,'vcautoresponderaddon_awebersubmit') );
		/* aweber */

		/* mailchimp */
		add_action( 'wp_ajax_vcautoresponderaddon_mailchimpsubmit', array($this,'vcautoresponderaddon_mailchimpsubmit') );
		add_action( 'wp_ajax_nopriv_vcautoresponderaddon_mailchimpsubmit', array($this,'vcautoresponderaddon_mailchimpsubmit') );
		/* mailchimp */

		/* getresponse */
		add_action( 'wp_ajax_vcautoresponderaddon_getresponsesubmit', array($this,'vcautoresponderaddon_getresponsesubmit') );
		add_action( 'wp_ajax_nopriv_vcautoresponderaddon_getresponsesubmit', array($this,'vcautoresponderaddon_getresponsesubmit') );
		/* getresponse */
		
		/* constant contact */
		add_action( 'wp_ajax_vcautoresponderaddon_constantcontactsubmit', array($this,'vcautoresponderaddon_constantcontactsubmit') );
		add_action( 'wp_ajax_nopriv_vcautoresponderaddon_constantcontactsubmit', array($this,'vcautoresponderaddon_constantcontactsubmit') );
		/* constant contact */
		
		/* icontact */
		add_action( 'wp_ajax_vcautoresponderaddon_icontactsubmit', array($this,'vcautoresponderaddon_icontactsubmit') );
		add_action( 'wp_ajax_nopriv_vcautoresponderaddon_icontactsubmit', array($this,'vcautoresponderaddon_icontactsubmit') );
		/* icontact */
	}

	public function enqueue_scripts(){
		wp_register_script( 'vcautoresponderaddon-custom', plugin_dir_url(__FILE__) . 'js/vcautoresponderaddon.js', array('jquery'), $this->version, false );
		wp_localize_script('vcautoresponderaddon-custom', 'ajaxobject', array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
			)
		);
	}

	public function enqueue_styles(){
		wp_register_style( 'vcautoresponderaddon-style', plugin_dir_url(__FILE__) . 'css/vcautoresponderaddon.css' );
		wp_register_style( 'vcaa-popupstyle', plugin_dir_url(__FILE__) . 'css/vcaa_popupstyle.css' );
		wp_register_style( 'vcaa-animated', plugin_dir_url(__FILE__) . 'css/animate.css' );
	}
	
	public function vcaa_registrater_sidebars(){
		global $wp_registered_sidebars;
		$this->vcaa_registrater_sidebars = $wp_registered_sidebars;
		add_filter( 'sidebars_widgets', array($this, 'vcaa_sidebars_widgets'), 0 );
	}
	
	public function vcaa_generate_widget($post, $sidebar_id){
		
		global $wp_registered_widgets;
		$instance = new Widget($post);
		$widget = $instance->get_widget();
		$widget_id = $instance->id;

		$wp_registered_widgets[$widget_id] = $widget;
		$sidebar_widgets = &$this->sidebars[ $sidebar_id ];
		if(!empty($sidebar_widgets)){
			$s_position = get_post_meta($post->ID,'settings_formposition',true);
			switch ( $s_position ) {
				case 'before':
					array_unshift( $sidebar_widgets, $widget_id );
					break;

				case 'after':
					$sidebar_widgets[] = $widget_id;
					break;

				case 'position':
					$position = get_post_meta($post->ID,'settings_formposition_value',true);
					if( $position ) {
						$position--;
					}
					array_splice( $sidebar_widgets, $position, 0, $widget_id);
					break;

				default:
					$sidebar_widgets = array( $widget_id );
					break;
			}
		}else{
			$sidebar_widgets = array( $widget_id );
		}
		return $widget_id;
	}
	
	public function vcaa_get_sidebar_post( $sidebar_slug ){
		$args = array (
			'post_type' => 'vcaa_sidebar',
			'name' => $sidebar_slug
		);
		$query = new WP_Query( $args );

		if( $query->have_posts() ) {
			$post = $query->post;
		}else{
			$post = array();
		}
		return $post;
	}
	
	public function vcaa_sidebars_widgets( $sidebars_widgets ){
		if( is_admin() ) {
			return $sidebars_widgets;
		}

		if( $this->enabled_vc_composer && vc_is_page_editable() ) {
			return $sidebars_widgets;
		}
		
		if( empty( $this->sidebars ) ) {
			$this->sidebars = &$sidebars_widgets;
			foreach( $this->vcaa_registrater_sidebars as $k=>$v ) {
				$post = $this->vcaa_get_sidebar_post( $k );
				if( $post && $post->post_status=='publish' ) {
					$this->vcaa_generate_widget( $post, $v['id'] );
				}
			}
		}
		return $this->sidebars;
	}

	public function get_videoID($url){
		$parsed = parse_url($url);
		$hostname = $parsed['host']; 
		if($hostname == 'www.youtube.com' || $hostname == 'youtube.com'){
			parse_str( parse_url( $url, PHP_URL_QUERY ), $id );
			return 'http://www.youtube.com/embed/'.$id['v'].'?rel=0&autoplay=1&showinfo=0&controls=0&enablejsapi=1';
		}elseif($hostname=='vimeo.com'){
			$ArrV = explode('://vimeo.com/',$path); // from ID to end of the string
			$videoID = substr($ArrV[0],1,8); // to get video ID , always length is 8 characters
			return 'http://player.vimeo.com/video/'.intval($videoID);
		}else{
			return '';
		}
	}
	
	public function vc_autoresponder_popup_container_shortcode($atts, $content = null){
		extract( shortcode_atts( array(
			'title' => '',
			'popupopacity' => '',
			'animatecls' => 'rotateIn',
			'showpopup' => '',
			'second' => '0',
			'popupwidth' => '',
			'popupshadow' => '',
			'popupshadowcolor' => '',
			'popupbgcolor' => '',
			'popupbgiamge' => ''
			), $atts ) );
		
		$result = '';
		
		if(!wp_style_is( 'vcaa-popupstyle', $list = 'enqueued' )){
			wp_enqueue_style('vcaa-popupstyle');
			wp_enqueue_style('vcaa-animated');
		}
		
		if(!wp_script_is( 'jquery' )) {
			wp_enqueue_script('jquery');
		}
		
		$rand = rand(1, 100);
		
		$url = ( !empty($popupbgiamge) ? 'url('.wp_get_attachment_image_src($popupbgiamge,'full')[0].');' : array() );
		
		$result .= '<div class="vcaa_popup_overlay'.( !empty($animatecls) ? ' vcaa_animated '.esc_attr($animatecls) : '' ).'" id="vcaapopup_'.esc_attr($rand).'" >';
			$result .= '<div class="vcaa_over_img" style="'.(!empty($url) ? 'background-image:'.$url : '').'"></div>';
			$result .= '<div class="vcaa_over_overlay" style="'.(!empty($popupopacity) ? 'opacity:'.($popupopacity/100).';' : '').(!empty($popupbgcolor) ? 'background-color:'.esc_attr($popupbgcolor).';' : '').'"></div>';
			$result .= '<a href="#" class="vcca_close vcca_close_'.esc_attr($rand).'"><img src="'.plugin_dir_url(__FILE__).'images/cross.png" alt=""/></a>';
			$result .= '<div class="vcaa_popup_box" style="'.(!empty($popupwidth) ? 'width:'.$popupwidth.'%;' : '').($popupshadow == 'Shadow' ? 'box-shadow: 4px 4px 30px '.$popupshadowcolor.';' : '' ).'">';
				$result .= do_shortcode($content);
			$result .= '</div>';
		$result .= '</div>';
		
		$result .= '<script>';
		$result .= 'var onetimeshowpopup = new Array();';
			if($showpopup == 'Onload'){
				$result .= 'jQuery(window).load(function() {
					jQuery("#vcaapopup_'.esc_attr($rand).'").fadeIn();
				});';
			}elseif($showpopup == 'End of page'){
				$result .= 'jQuery(window).scroll(function() {
					if(!(jQuery.inArray("vcaapopup_'.esc_attr($rand).'",onetimeshowpopup) > -1)){
						if(jQuery(window).scrollTop() + jQuery(window).height() == jQuery(document).height()) {
							onetimeshowpopup.push("vcaapopup_'.esc_attr($rand).'");
							jQuery("#vcaapopup_'.esc_attr($rand).'").fadeIn();
						}
					}
				});';
			}elseif($showpopup == 'After scrolling midway'){
				$result .= 'jQuery(window).scroll(function() {
					if(!(jQuery.inArray("vcaapopup_'.esc_attr($rand).'",onetimeshowpopup) > -1)){
						if (jQuery(window).scrollTop()  > jQuery(window).height() / 2){
							onetimeshowpopup.push("vcaapopup_'.esc_attr($rand).'");
							jQuery("#vcaapopup_'.esc_attr($rand).'").fadeIn();
						}
					}
				});';
			}elseif($showpopup == 'After X seconds'){
				$result .= 'setTimeout(function(){
					jQuery("#vcaapopup_'.esc_attr($rand).'").fadeIn();
				}, '.($second * 1000).');';
			}
			$result .= 'jQuery(document).ready(function(){
				jQuery(".vcca_close_'.esc_attr($rand).'").on(\'click\', function(e) {
					e.preventDefault();
					jQuery(this).parent(\'.vcaa_popup_overlay\').fadeOut();
				});
			});';
		$result .= '</script>';
		
		return $result;
	}

	public function vc_autoresponder_form_shortcode($atts, $content = null){
		extract( shortcode_atts( array(
			'title' => '',
			'autoresponder' => '',
			'aweberlistid' => '',
			'mailchimplistid' => '',
			'getresponselistid' => '',
			'constantcontactlistid' => '',
			'icontactlistid' => '',
			'padding' => '0',
			'vcformtitlecolor' => '#ffffff',
			'vcformbgimg' => '',
			'bgpattern' => '',
			'vcformbgvideo' => '',
			'second' => '',
			'bgtype' => '',
			'vcformbgcolor' => '',
			'vcvideoformbgcolor' => '#ffffff',
			'closebtn' => '',
			'opacity' => ''
		), $atts ) );

		$result = '';

		if(!wp_script_is( 'vcautoresponderaddon-custom', 'enqueued' )) {
			wp_enqueue_script( 'vcautoresponderaddon-custom' );
			wp_localize_script('vcautoresponderaddon-custom', 'ajaxobject', array(
					'ajaxurl' => admin_url( 'admin-ajax.php' ),
				)
			);
			wp_enqueue_style('vcautoresponderaddon-style');
		}

		$url = ( ( $bgtype == 'image' && !empty($vcformbgimg) ) ? wp_get_attachment_image_src($vcformbgimg,'full') : array() );

		$videourl = ( ( $bgtype == 'video' && !empty($vcformbgvideo) ) ? $vcformbgvideo : '' );

		$videourl = !empty($videourl) ? $this->get_videoID($videourl) : '';
		
		$bgpattern = ($bgtype == 'Background Pattern' ? 'vcautoresponder_'.str_replace(' ', '_', $bgpattern) : '');
		
		

		$result .= '<div class="vcautoresponderaddon_form_wrapper'.(!empty($videourl) ? ' vcautoresponderaddon_videoversion' : '').'" style="'.(isset($url[0]) ? 'background-image:url('.esc_url($url[0]).');' : '').'padding:'.esc_attr($padding).'px;" >';

			$rand = rand();
			
			if(!empty($videourl)){
				$result .= '<div class="vcautoresponderaddon_videoiframe" id="vcaa'.esc_attr($rand).'"><iframe width="100%" height="100%" src="'.esc_url($videourl).'" ></iframe></div>';
			}
			$result .= '<div class="vcautoresponderaddon_loader"><div class="loader">Loading...</div></div>';
			$result .= '<div class="vcautoresponderaddon_overlay '.esc_attr($bgpattern).'" style="'.(!empty($opacity) || $opacity == '0' ? 'opacity:'.($opacity/100).';' : '').(!empty($vcformbgcolor) ? 'background-color:'.esc_attr($vcformbgcolor).';' : '').'"></div>';
			
			$result .= '<div class="vcautoresponderaddon_mainform'.(!empty($videourl) ? ' vcautoresponderaddon_onload_a_second' : '').'" '.(!empty($videourl) ? 'id="vcaashow'.esc_attr($rand).'" style="'.(!empty($vcvideoformbgcolor) ? 'background-color:'.esc_attr($vcvideoformbgcolor).';' : '').'"' : '').'>';

				if(!empty($videourl) && $closebtn == 'yes'){
					$result .= '<a class="vcautoresponderaddon_closebtn" onclick="formclose'.esc_attr($rand).'();"><svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="44.238px" height="44.238px" viewBox="0 0 44.238 44.238" style="enable-background:new 0 0 44.238 44.238;" xml:space="preserve"><g><g><g><path d="M15.533,29.455c-0.192,0-0.384-0.073-0.53-0.22c-0.293-0.293-0.293-0.769,0-1.062l13.171-13.171c0.293-0.293,0.768-0.293,1.061,0s0.293,0.768,0,1.061L16.063,29.235C15.917,29.382,15.725,29.455,15.533,29.455z"/></g><g><path d="M28.704,29.455c-0.192,0-0.384-0.073-0.53-0.22L15.002,16.064c-0.293-0.293-0.293-0.768,0-1.061s0.768-0.293,1.061,0l13.171,13.171c0.293,0.293,0.293,0.769,0,1.062C29.088,29.382,28.896,29.455,28.704,29.455z"/></g><path d="M22.119,44.237C9.922,44.237,0,34.315,0,22.12C0,9.924,9.922,0.001,22.119,0.001S44.238,9.923,44.238,22.12S34.314,44.237,22.119,44.237z M22.119,1.501C10.75,1.501,1.5,10.751,1.5,22.12s9.25,20.619,20.619,20.619s20.619-9.25,20.619-20.619S33.488,1.501,22.119,1.501z"/></g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g></svg></a>';
				}

				$result .= (!empty($title) ? '<h2 style="color:'.esc_attr($vcformtitlecolor).';">'.esc_html($title).'</h2>' : '' );

				$result .= '<form method="post" class="vcautoresponderaddon_autoresponder" onSubmit="return false;">';
					$result .= '<input type="hidden" value="'.esc_attr($autoresponder).'" class="autoresponder">';
					$result .= '<input type="hidden" value="'.($autoresponder == 'Aweber' ? esc_attr($aweberlistid) : ($autoresponder == 'Mailchimp' ? esc_attr($mailchimplistid) : ($autoresponder == 'Getresponse' ? esc_attr($getresponselistid) : ($autoresponder == 'Constant Contact' ? esc_attr($constantcontactlistid) : ($autoresponder == 'iContact' ? esc_attr($icontactlistid) : ''))) ) ).'" class="vcautoresponder_listid">';
					$result .= do_shortcode($content);
				$result .= '</form>';

				$result .= '<div class="autoresponderaddon_submit_msg" style="color:'.(esc_html(get_option('vcsuccessmsgcolor'))).';"><p>'.esc_html(get_option('vcsuccessmsgtxt')).'</p></div>';
				
			$result .= '</div>';

		$result .= '</div>';

		if(!empty($videourl) && $second >= 0){
			$result .= '<script>
				setTimeout(function(){
					document.getElementById("vcaashow'.esc_attr($rand).'").style.display = "block";
					var div = document.getElementById("vcaa'.esc_attr($rand).'");
					var iframe = div.getElementsByTagName("iframe")[0].contentWindow;
					var func = "stopVideo";
					iframe.postMessage(\'{"event":"command","func":"pauseVideo","args":""}\', "*");
					}, '.($second*1000).');
				function formclose'.esc_attr($rand).'(){
					document.getElementById("vcaashow'.esc_attr($rand).'").style.display = "none";
					document.getElementById("vcaashow'.esc_attr($rand).'").previousSibling.style.display = "none";
					var div = document.getElementById("vcaa'.esc_attr($rand).'");
					var iframe = div.getElementsByTagName("iframe")[0].contentWindow;
					var func = "stopVideo";
					iframe.postMessage(\'{"event":"command","func":"playVideo","args":""}\', "*");					
				}
			</script>';
		}
		
		//$result .= '<div class="vcautoresponderaddon_successmessage">Subscribe Successfully.</div>';
		
		return $result;
	}

	public function vc_autoresponder_form_field_shortcode($atts, $content = null){
		extract( shortcode_atts( array(
			'field' => '',
			'customfield' => '',
			'placeholder' => '',
			'labeltxt' => '',
			'vclabletxtcolor' => '#ffffff',
			'require' => '',
			'errortxt' => '',
			'errortxtcolor' => '#ff1616',
			'buttonalign' => 'left',
			'buttontxt' => '',
			'buttonbgcolor' => '',
			'buttontxtcolor' => '',
		), $atts ) );

		$result = '';

		$color = get_option('vcerrormsgcolor');
		
		switch($field){
			case 'name field':
				$result .= '<div class="vcautoresponderaddon_input_wrapper">';
				$result .= (!empty($labeltxt) ? '<label style="color:'.esc_attr($vclabletxtcolor).';">'.esc_html($labeltxt).'</label>' : '' );
				$result .= '<input type="text" name="name" '.(!empty($placeholder) ? 'placeholder="'.esc_attr($placeholder).'"' : '').' data-req="'.($require == 'yes' ? 'name' : '0').'" data-error-msg="'.esc_attr($errortxt).'">';
				$result .= '<span style="color:'.esc_attr($errortxtcolor).';"></span>';
				$result .= '</div>';
			break;
			case 'email field':
				$result .= '<div class="vcautoresponderaddon_input_wrapper">';
				$result .= (!empty($labeltxt) ? '<label style="color:'.esc_attr($vclabletxtcolor).';">'.esc_html($labeltxt).'</label>' : '' );
				$result .= '<input type="text" name="email" '.(!empty($placeholder) ? 'placeholder="'.esc_attr($placeholder).'"' : '').' data-req="'.($require == 'yes' ? 'email' : '0').'" data-error-msg="'.esc_attr($errortxt).'">';
				$result .= '<span style="color:'.esc_attr($errortxtcolor).';"></span>';
				$result .= '</div>';
			break;
			case 'custom field':
				$result .= '<div class="vcautoresponderaddon_input_wrapper">';
				$result .= (!empty($labeltxt) ? '<label style="color:'.esc_attr($vclabletxtcolor).';">'.esc_html($labeltxt).'</label>' : '' );
				$result .= '<input type="text" name="'.$customfield.'" '.(!empty($placeholder) ? 'placeholder="'.esc_attr($placeholder).'"' : '').' data-req="'.($require == 'yes' ? 'custom' : '0').'" data-error-msg="'.esc_attr($errortxt).'">';
				$result .= '<span style="color:'.esc_attr($errortxtcolor).';"></span>';
				$result .= '</div>';
			break;
			case 'button field':
				$result .= '<div class="vcautoresponderaddon_input_wrapper" style="'.($buttonalign == 'center' || $buttonalign == 'left' || $buttonalign == 'right' ? 'text-align:'.esc_attr($buttonalign).';' : '' ).'"><button type="submit" name="submit" style="'.(!empty($buttonbgcolor) ? 'background-color:'.esc_attr($buttonbgcolor).';' : '').(!empty($buttontxtcolor) ? 'color:'.esc_attr($buttontxtcolor).';' : '').($buttonalign == 'justify' ? 'width:100%;' : '').'">'.esc_attr($buttontxt).'</button></div>';
			break;
		}
		
		return $result;
	}

	public function vcautoresponderaddon_awebersubmit(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcautoresponderaddon_awebersubmit'){
			//print_r($_POST);
			require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/aweber/aweber_api.php';
			$aweberapi = get_option('vcaweber_authinfoDB');
			$listid = $_POST['listid'];
			if(!empty($aweberapi) && !empty($listid)){
				try{
					$aweber = new AWeberAPI($aweberapi['consumer_key'], $aweberapi['consumer_secret']);
					$account = $aweber->getAccount($aweberapi['access_key'], $aweberapi['access_secret']);
					$aweber_list = $listid;
					$list = $account->loadFromUrl('/accounts/' . $account->id . '/lists/' . $aweber_list);
					$custom_fields = $list->custom_fields;
					$vcautoresponderaddon_custom_fields = array();
					/*try {*/
						foreach($_POST as $k=>$v){
							if(!($k == 'name' || $k == 'email' || $k == 'action' || $k == 'listid')){
								/* $field = get_option('vcautoresponderaddon_'.$k);
								if($field != 'yes'){
									# setup your custom fields
									$custom_fields->create(array('name' => $k));
									update_option('vcautoresponderaddon_'.$k,'yes');
								} */
								$vcautoresponderaddon_custom_fields[$k] = $v;
							}
						}					
					/* }catch(AWeberAPIException $exc) {
						echo json_encode(array('error' => $exc->message ));
					} */
					if(!empty($vcautoresponderaddon_custom_fields)){
						$subscriber = array( 
							'email' => $_POST['email'],
							'custom_fields' => $vcautoresponderaddon_custom_fields,
							'ip' => $_SERVER['REMOTE_ADDR']
						);
					}else{
						$subscriber = array( 
							'email' => $_POST['email'],
							'ip' => $_SERVER['REMOTE_ADDR']
						);
					}
					
					if (!empty($_POST['name'])){ 
						$subscriber['name'] = $_POST['name'];  
					}
					$result = $list->subscribers->create($subscriber);
					//print_r($result);
					//print_r($subscriber);
					echo json_encode(array('success'=>'Subccribe Successfully.'));
				}catch(AWeberException $e){
					echo json_encode(array('error' => $e->message));
				}
			}else{
				echo json_encode(array('error' => 'Please ReCheck Aweber API Settings.'));
			}
			die();
		}
	}

	public function vcautoresponderaddon_mailchimpsubmit(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcautoresponderaddon_mailchimpsubmit'){
			$apikey = get_option('vcmailchimp_apikey');
			$listId = $_POST['listid'];
			if(!empty($apikey) && !empty($listId)){
				require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/mailchimp/MCAPI.class.php';
				
				$api = new MailChimp($apikey);
				
				$merge_vars = array();
				
				foreach($_POST as $k=>$v){
					if($k == 'name'){
						$merge_vars['FNAME'] = $v;
					}
					if(!($k == 'name' || $k == 'email' || $k == 'action' || $k == 'listid')){
						$merge_vars[$k] = $v;
					}
				}
				$my_email = $_POST['email'];
				if(!empty($my_email)){
					if(!empty($listId)){
        				$mdata = $api->post("lists/$listId/members", [
        					'email_address' => $my_email,
        					'status'        => 'subscribed',
        				]);
        			}
				}
				
				if ($api->success()) {
    				if(!empty($merge_vars)){
    					$subscriber_hash = $api->subscriberHash( $_POST['email'] );
    					$api->patch("lists/$listId/members/$subscriber_hash", [
    						'merge_fields' => $merge_vars
    					]);
    				}
    				$result = array('success'=>'Subccribe Successfully.');
    			}elseif ($mdata['status'] == 400){
    				$error = $_POST['email'] . ' is already a list member.';
    				$result = array( 'error'=> $error );
    			}else{
    				$result = array( 'error'=> 'Error: ' . $api->getLastError() );
    			}
    			
    			echo json_encode($result);
				
			}
			die();
		}
	}
	 
	public function vcautoresponderaddon_getresponsesubmit(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcautoresponderaddon_getresponsesubmit'){
			$apikey = get_option('vcgetresponse_apikey');
			$listId = $_POST['listid'];
			if(!empty($apikey) && !empty($listId)){
				// require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/getresponse/jsonRPCClient.php';
				
				// $api = new jsonRPCClient('http://api2.getresponse.com');
				// try{
					
				// 	if(!empty($listId)){
				// 		$args = array(
				// 			'campaign' => $listId,
				// 			'email' => $_POST['email'],
				// 		);
				// 	}
				// 	$arr = array();
				// 	foreach($_POST as $k=>$v){
				// 		if($k == 'name'){
				// 			$args['name'] = $v;
				// 		}
				// 		if(!($k == 'name' || $k == 'email' || $k == 'action' || $k == 'listid')){
				// 			$arr[] = array(
				// 				'name'       => $k,
				// 				'content'    => $v
				// 			);
				// 		}
				// 	}
				// 	$args['customs'] = $arr;
				// 	//print_r($args);
				// 	$res = $api->add_contact($apikey, $args);
					
				// 	echo json_encode(array('success'=>'Subccribe Successfully.'));
					
				// }catch (Exception $e){
				// 	//echo $e->getMessage();
				// 	echo json_encode(array('error' => $e->getMessage()));
				// 	//echo $e->getMessage();
				// }
				// die();
				
				$curl = curl_init();
    			$name = !empty($_POST['name']) ? $_POST['name'] : 'Subscriber';
    			$list = $listId;
    			$email = $_POST['email'];
    			$key = $apikey;
    
    			curl_setopt_array($curl, array(
    			  CURLOPT_URL => "https://api.getresponse.com/v3/contacts",
    			  CURLOPT_RETURNTRANSFER => true,
    			  CURLOPT_ENCODING => "",
    			  CURLOPT_MAXREDIRS => 10,
    			  CURLOPT_TIMEOUT => 0,
    			  CURLOPT_FOLLOWLOCATION => true,
    			  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    			  CURLOPT_CUSTOMREQUEST => "POST",
    			 CURLOPT_POSTFIELDS => '{
    				"name": "'.$name.'",
    				"campaign": {
    				"campaignId": "'.$list.'"
    				},
    				"email": "'.$email.'"
    				}',
    			  CURLOPT_HTTPHEADER => array(
    				'X-Auth-Token: api-key '.$key.'',
    				"content-type: application/json"
    			  ),
    			));
    
    			$response = curl_exec($curl);
    
    			curl_close($curl);
    			if(empty($response)){
    				echo json_encode(array('success'=>'Subscribe successfully.'));
    			}else{
    				$res = json_decode($response);
    				echo json_encode(array('error'=> $res->message));
    			}
    			die();
    			return $response;
			}
			die();
		}
	}   

	public function vcautoresponderaddon_constantcontactsubmit(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcautoresponderaddon_constantcontactsubmit'){
			$ccinfo = get_option('vcconstantcontact_apikey');
			if(!empty($ccinfo) && !empty($_POST['listid'])){
				// require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/constantcontact/class.cc.php';
				// $cc = new cc($ccinfo['username'], $ccinfo['password']);
				// $email = $_POST['email'];
				// if(!empty($_POST['listid'])){
				// 	$contact_list = $_POST['listid'];
				// }
				// $extra_fields = array();
				// foreach($_POST as $k=>$v){
				// 	if($k == 'name'){
				// 		$extra_fields['FirstName'] = $v;
				// 	}
				// 	if(!($k == 'name' || $k == 'email' || $k == 'action' || $k == 'listid')){
				// 		$extra_fields[$k] = $v;
				// 	}
				// }
				// $contact = $cc->query_contacts($email);
				// if ($contact){
				//   echo json_encode(array('error' =>'This Email Already Subccribe'));
				// }
				// else{
				// 	$new_id = $cc->create_contact($email, $contact_list, $extra_fields);
				// 	if ($new_id){
				// 		echo json_encode(array('success'=>'Subccribe Successfully.'));
				// 	}else{
				// 		echo json_encode(array('error' =>$cc->http_response_body));					
				// 	}
				// }
				
				$email = $_POST['email'];
				$listid = $_POST['listid'];
				$token = get_option('vcconstantcontact_token');
				$name = '';
				$name = !empty($name) ? $name : '';
				$curl = curl_init();
				curl_setopt_array($curl, array(
				  CURLOPT_URL => "https://api.cc.email/v3/contacts",
				  CURLOPT_RETURNTRANSFER => true,
				  CURLOPT_ENCODING => "",
				  CURLOPT_MAXREDIRS => 10,
				  CURLOPT_TIMEOUT => 0,
				  CURLOPT_FOLLOWLOCATION => true,
				  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
				  CURLOPT_CUSTOMREQUEST => "POST",
				  CURLOPT_POSTFIELDS => '{"email_address": {"address": "'.$email.'","permission_to_send": "implicit"},"first_name":"'.$name.'","create_source": "Account","list_memberships": ["'.$listid.'"]}',
				  CURLOPT_HTTPHEADER => array(
					'authorization: Bearer '.$token.'',
					"content-type: application/json",
					"cache-control: no-cache",
					"accept: application/json"
				  ),
				));

				$response = curl_exec($curl);
				curl_close($curl);
				
				$res = json_decode($response);
				if(isset($res->contact_id)){
					echo json_encode(array('msg' => 'Thank you, we have successfully subscribed your email.', 'status' => 'success'));
				}elseif(str_contains($res[0]->error_message, 'Email already exists')){
					echo json_encode(array('msg'=> 'Email already exists.', 'status' => 'error'));
				}else{
					echo json_encode(array('msg'=> $res[0]->error_message, 'status' => 'error'));
				}
			}
			die();
		}
	}
	
	public function vcautoresponderaddon_icontactsubmit(){
		if(isset($_POST['action']) && $_POST['action'] == 'vcautoresponderaddon_icontactsubmit'){
			$icontactinfo = get_option('vcicontact_apikey');
			if(!empty($icontactinfo) && !empty($_POST['listid'])){
				require_once plugin_dir_path( dirname( __FILE__ ) ) . '/includes/icontact/iContactApi.php';
				
				iContactApi::getInstance()->setConfig(array(
					'appId' => $icontactinfo['appid'],
					'apiPassword' => $icontactinfo['apppassword'],
					'apiUsername' => $icontactinfo['username']
				));
				$listid = $_POST['listid'];
			
				$oiContact = iContactApi::getInstance();
				
				$arr = array();
				
				foreach($_POST as $k=>$v){
					if(!($k == 'name' || $k == 'email' || $k == 'action' || $k == 'listid')){
						$arr[$k] = $v;
					}
				}
				
				$res1 = $oiContact->addContact($_POST['email'], null, null, (isset($_POST['name']) ? $_POST['name'] : ''), null, null, null, null, null, null, null, null, null, null,$arr);
				if ($res1->contactId){
					if ($oiContact->subscribeContactToList($res1->contactId, $listid, 'normal')){
						echo json_encode(array('success'=>'Subccribe Successfully.'));
					}
				}else{
					echo json_encode(array('error' =>'Please ReCheck iContact API Settings.'));
				}
			}else{
				echo json_encode(array('error' =>'Please ReCheck iContact API Settings.'));
			}
			die();
		}
	}
}
?>